==> vdocipher_flutter-2.2.7.tar.gz: android/src/main/java/com/vdocipher/flutter/vdoplayer/EmbedInfoToVdoInitParams.java <==
package com.vdocipher.flutter.vdoplayer;

import com.vdocipher.aegis.player.VdoInitParams;

import org.json.JSONArray;

import java.time.Duration;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Map;

/**
 * Converts an embedInfo map received from Dart to a VdoInitParams object.
 * <p>
 * Map received from Dart has all the available keys, set to null if a value wasn't explicitly set.
 */
public final class EmbedInfoToVdoInitParams {
    private final Map<String, Object> embedInfo;

    public EmbedInfoToVdoInitParams(Map<String, Object> embedInfo) {
        this.embedInfo = embedInfo;
    }

    public VdoInitParams convert() {
        VdoInitParams.Builder builder = new VdoInitParams.Builder();

        final boolean offline = (boolean) embedInfo.get("offline");
        if (offline) {
            builder.setOfflinePlayback((String) embedInfo.get("mediaId"));
        } else {
            builder.setOtp((String) embedInfo.get("otp"));
            builder.setPlaybackInfo((String) embedInfo.get("playbackInfo"));
        }

        final Map<String, Object> embedInfoOptions = (Map<String, Object>) embedInfo.get("embedInfoOptions");
        if (embedInfoOptions != null) {
            if (embedInfoOptions.get("safetyNetApiKey") != null)
                builder.setSafetyNetApiKey((String) embedInfoOptions.get("safetyNetApiKey"));
            if (embedInfoOptions.get("preferredCaptionsLanguage") != null)
                builder.setPreferredCaptionsLanguage((String) embedInfoOptions.get("preferredCaptionsLanguage"));
            if (embedInfoOptions.get("startTimeMs") != null || embedInfoOptions.get("endTimeMs") != null) {
                int startTimeMs = embedInfoOptions.get("startTimeMs") != null ?
                        (int) embedInfoOptions.get("startTimeMs") : 0;
                int endTimeMs = embedInfoOptions.get("endTimeMs") != null ?
                        (int) embedInfoOptions.get("endTimeMs") : Integer.MAX_VALUE;
                builder.setClips(startTimeMs, endTimeMs);
            }
            if (embedInfoOptions.get("resumeTimeMs") != null)
                builder.setResumeTime((int) embedInfoOptions.get("resumeTimeMs"));
            if (embedInfoOptions.get("maxVideoBitrateKbps") != null)
                builder.setMaxVideoBitrateKbps((int) embedInfoOptions.get("maxVideoBitrateKbps"));
            if (embedInfoOptions.get("bufferingGoalMs") != null)
                builder.setBufferingGoalMs((int) embedInfoOptions.get("bufferingGoalMs"));
            if (embedInfoOptions.get("disableAnalytics") != null)
                builder.setDisableAnalytics((boolean) embedInfoOptions.get("disableAnalytics"));
            if (embedInfoOptions.get("allowAdbDebugging") != null)
                builder.setAllowAdbDebugging((boolean) embedInfoOptions.get("allowAdbDebugging"));
            if (embedInfoOptions.get("autoplay") != null)
                builder.setAutoplay((boolean) embedInfoOptions.get("autoplay"));
            if (embedInfoOptions.get("forceLowestBitrate") != null)
                builder.setForceLowestBitrate((boolean) embedInfoOptions.get("forceLowestBitrate"));
            if (embedInfoOptions.get("forceHighestSupportedBitrate") != null)
                builder.setForceHighestSupportedBitrate((boolean) embedInfoOptions.get("forceHighestSupportedBitrate"));
            if (embedInfoOptions.get("techOverride") != null) {
                ArrayList<String> overrideList = (ArrayList<String>) embedInfoOptions.get("techOverride");
                builder.setTechOverride(overrideList.toArray(new String[0]));
            }
            if (embedInfoOptions.get("configMap") != null) {
                HashMap<String, Object> configMap = (HashMap<String, java.lang.Object>) embedInfo.get("configMap");
                builder.updateConfig(configMap);
            }
            if (embedInfoOptions.get("customPlayerId") != null)
                builder.setPlayerConfig((String) embedInfoOptions.get("customPlayerId"));
            if (embedInfoOptions.get("allowAutoResume") != null) {
                boolean allowAutoResume = (Boolean) embedInfoOptions.get("allowAutoResume");
                if (allowAutoResume)
                    builder.enableAutoResume();
            }
        }
        return builder.build();
    }
}

==> vdocipher_flutter-2.6.0.tar.gz: android/src/main/java/com/vdocipher/flutter/vdoplayer/EmbedInfoToVdoInitParams.java <==
package com.vdocipher.flutter.vdoplayer;

import android.util.Log;

import com.vdocipher.aegis.player.VdoInitParams;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.Map;

/**
 * Converts an embedInfo map received from Dart to a VdoInitParams object.
 * <p>
 * Map received from Dart has all the available keys, set to null if a value wasn't explicitly set.
 */
public final class EmbedInfoToVdoInitParams {
    private final Map<String, Object> embedInfo;

    public EmbedInfoToVdoInitParams(Map<String, Object> embedInfo) {
        this.embedInfo = embedInfo;
    }

    public VdoInitParams convert() {
        VdoInitParams.Builder builder = new VdoInitParams.Builder();

        final boolean offline = (boolean) embedInfo.get("offline");
        if (offline) {
            builder.setOfflinePlayback((String) embedInfo.get("mediaId"));
        } else {
            builder.setOtp((String) embedInfo.get("otp"));
            builder.setPlaybackInfo((String) embedInfo.get("playbackInfo"));
        }

        final Map<String, Object> embedInfoOptions = (Map<String, Object>) embedInfo.get("embedInfoOptions");
        if (embedInfoOptions != null) {
            if (embedInfoOptions.get("preferredCaptionsLanguage") != null)
                builder.setPreferredCaptionsLanguage((String) embedInfoOptions.get("preferredCaptionsLanguage"));
            if (embedInfoOptions.get("startTimeMs") != null || embedInfoOptions.get("endTimeMs") != null) {
                int startTimeMs = embedInfoOptions.get("startTimeMs") != null ?
                        (int) embedInfoOptions.get("startTimeMs") : 0;
                int endTimeMs = embedInfoOptions.get("endTimeMs") != null ?
                        (int) embedInfoOptions.get("endTimeMs") : Integer.MAX_VALUE;
                builder.setClips(startTimeMs, endTimeMs);
            }
            if (embedInfoOptions.get("resumeTimeMs") != null)
                builder.setResumeTime((int) embedInfoOptions.get("resumeTimeMs"));
            if (embedInfoOptions.get("maxVideoBitrateKbps") != null)
                builder.setMaxVideoBitrateKbps((int) embedInfoOptions.get("maxVideoBitrateKbps"));
            if (embedInfoOptions.get("bufferingGoalMs") != null)
                builder.setBufferingGoalMs((int) embedInfoOptions.get("bufferingGoalMs"));
            if (embedInfoOptions.get("disableAnalytics") != null)
                builder.setDisableAnalytics((boolean) embedInfoOptions.get("disableAnalytics"));
            if (embedInfoOptions.get("allowAdbDebugging") != null)
                builder.setAllowAdbDebugging((boolean) embedInfoOptions.get("allowAdbDebugging"));
            if (embedInfoOptions.get("autoplay") != null)
                builder.setAutoplay((boolean) embedInfoOptions.get("autoplay"));
            if (embedInfoOptions.get("forceLowestBitrate") != null)
                builder.setForceLowestBitrate((boolean) embedInfoOptions.get("forceLowestBitrate"));
            if (embedInfoOptions.get("forceHighestSupportedBitrate") != null)
                builder.setForceHighestSupportedBitrate((boolean) embedInfoOptions.get("forceHighestSupportedBitrate"));
            if (embedInfoOptions.get("techOverride") != null) {
                ArrayList<String> overrideList = (ArrayList<String>) embedInfoOptions.get("techOverride");
                builder.setTechOverride(overrideList.toArray(new String[0]));
            }
            if (embedInfoOptions.get("configMap") != null) {
                HashMap<String, Object> configMap = (HashMap<String, java.lang.Object>) embedInfo.get("configMap");
                builder.updateConfig(configMap);
            }
            if (embedInfoOptions.get("customPlayerId") != null)
                builder.setCustomPlayer((String) embedInfoOptions.get("customPlayerId"));
            if (embedInfoOptions.get("allowAutoResume") != null) {
                boolean allowAutoResume = (Boolean) embedInfoOptions.get("allowAutoResume");
                if (allowAutoResume)
                    builder.enableAutoResume();
            }
        }
        return builder.build();
    }
}
